@@ -13,6 +13,7 @@ import os
 SENSOR_NAME_VARIATION = {
     'alos'  : ['alos', 'alos1', 'palsar', 'palsar1'],
     'alos2' : ['alos2', 'palsar2'],
+    'alos4' : ['alos4', 'palsar3'],
     'csk'   : ['csk', 'csk1', 'csk2', 'csk3', 'csk4', 'cos', 'cosmo', 'cosmoskymed'],
     'env'   : ['env', 'envisat', 'asar'],
     'ers'   : ['ers', 'ers1', 'ers2', 'ers12'],
@@ -197,10 +198,16 @@ def get_unavco_mission_name(meta_dict):
 ##--------------------  X-band  --------------------##
 # TerraSAR-X stripmap mode in single polarization
 # from Table 1 in Jung et al. (2014)
+# https://www.eoportal.org/satellite-missions/terrasar-x
 TSX = {
+    # orbit
+    'altitude'                   : 514.8e3,   # m, mean value, 505-533 km
+    'orbit_inclination'          : 97.44,     # deg
+    'repeat_cycle'               : 11,        # day
+    # sar / antenna
     'carrier_frequency'          : 9.65e9,    # Hz
-    'altitude'                   : 516e3,     # m, mean value
     'antenna_length'             : 4.8,       # m
+    'antenna_width'              : 0.8,       # m
     'doppler_bandwidth'          : 2770,      # Hz
     'pulse_repetition_frequency' : 3800,      # Hz
     'chirp_bandwidth'            : 100e6,     # Hz
@@ -211,10 +218,16 @@ TSX = {
 
 # COSMO-SkyMed stripmap HIMAGE mode
 # from Table 1 in Jung et al. (2014)
+# https://www.eoportal.org/satellite-missions/cosmo-skymed
 CSK = {
+    # orbit
+    'altitude'                   : 619.6e3,   # m, mean value
+    'orbit_inclination'          : 97.86,     # deg
+    'repeat_cycle'               : 16,        # day, single satellite
+    # sar / antenna
     'carrier_frequency'          : 9.6e9,     # Hz
-    'altitude'                   : 619e3,     # m, mean value
     'antenna_length'             : 5.7,       # m
+    'antenna_width'              : 1.4,       # m
     'doppler_bandwidth'          : 2670,      # Hz
     'pulse_repetition_frequency' : 3000,      # Hz
     'chirp_bandwidth'            : 117e6,     # Hz
@@ -223,11 +236,16 @@ CSK = {
     'ground_range_pixel_size'    : 1.6,       # m
 }
 
-# Kompsat-5 stripmap mode
+# Kompsat-5 (Korea Multi-Purpose Satellite-5) stripmap mode
 # from Table 1 in Jung et al. (2014)
+# https://www.eoportal.org/satellite-missions/kompsat-5
 KSAT5 = {
-    'carrier_frequency'          : 9.66e9,    # Hz
+    # orbit
     'altitude'                   : 550e3,     # m, mean value
+    'orbit_inclination'          : 98.1,      # deg
+    'repeat_cycle'               : 28,        # day
+    # sar / antenna
+    'carrier_frequency'          : 9.66e9,    # Hz
     'antenna_length'             : 4.48,      # m
     'doppler_bandwidth'          : 3110,      # Hz
     'pulse_repetition_frequency' : 3530,      # Hz
@@ -240,9 +258,14 @@ KSAT5 = {
 # ICEYE SAR constellation
 # from Table 2.1 in ICEYE SAR Product Guide at:
 # https://earth.esa.int/eogateway/documents/20142/37627/ICEYE-SAR-Product-Guide-V4.pdf
+# https://www.eoportal.org/satellite-missions/iceye-constellation
 ICEYE = {
+    # orbit
+    'altitude'                   : 570e3,           # m, mean value, 560-580 km
+    'orbit_inclination'          : 97.7,            # deg
+    'repeat_cycle'               : 17,              # day, single satellite
+    # sar / antenna
     'carrier_frequency'          : 9.65e9,          # Hz
-    'altitude'                   : 570e3,           # m
     'antenna_length'             : 3.2,             # m
     'antenna_width'              : 0.4,             # m
     'pulse_repetition_frequency' : [2e3, 10e3],     # Hz
@@ -255,10 +278,17 @@ ICEYE = {
 # ERS-1/2
 # from Table 2 in Jung et al. (2014)
 # from Imaging Radar class by Howard Zebker, 2021.
+# https://www.esa.int/esapub/bulletin/bullet83/duc83.htm
+# https://www.eoportal.org/satellite-missions/ers-1
 ERS = {
-    'carrier_frequency'          : 5.300e9,     # Hz
-    'altitude'                   : 783e3,       # m, mean value
+    # orbit
+    'altitude'                   : 785e3,       # m, mean value, 782-785 km
+    'orbit_inclination'          : 98.52,       # deg
+    'repeat_cycle'               : 35,          # day
+    # sar / antenna
+    'carrier_frequency'          : 5.30e9,      # Hz
     'antenna_length'             : 10.0,        # m
+    'antenna_width'              : 1.0,         # m
     'doppler_bandwidth'          : 1500,        # Hz
     'pulse_repetition_frequency' : 1679.9,      # Hz
     'pulse_length'               : 37.12e-6,    # s
@@ -271,10 +301,17 @@ ERS = {
 
 # Envisat
 # from Table 2 in Jung et al. (2014)
+# https://earth.esa.int/eogateway/missions/envisat/description
+# https://www.eoportal.org/satellite-missions/envisat#asar-advanced-sar
 ENV = {
+    # orbit
+    'altitude'                   : 799.8e3,   # m, mean value, 780-820 km
+    'orbit_inclination'          : 98.55,     # deg
+    'repeat_cycle'               : 35,        # day
+    # sar / antenna
     'carrier_frequency'          : 5.331e9,   # Hz
-    'altitude'                   : 800e3,     # m, mean value
     'antenna_length'             : 10.0,      # m
+    'antenna_width'              : 1.3,       # m
     'doppler_bandwidth'          : 1500,      # Hz
     'pulse_repetition_frequency' : 1650,      # Hz
     'chirp_bandwidth'            : 16.00e6,   # Hz
@@ -283,11 +320,28 @@ ENV = {
     'ground_range_pixel_size'    : 21.3,      # m
 }
 
+# Radarsat-1
+# https://www.asc-csa.gc.ca/eng/satellites/radarsat/technical-features/radarsat-comparison.asp
+RSAT1 = {
+    # orbit
+    'altitude'                   : 807e3,     # m, mean value, 793-821 km
+    'orbit_inclination'          : 98.6,      # deg
+    'repeat_cycle'               : 14,        # day, 14.29 orbits per day (14 7/24)
+    # sar / antenna
+    'carrier_frequency'          : 5.3e9,     # Hz
+    'antenna_length'             : 15,        # m
+    'antenna_width'              : 1.5,       # m
+}
+
 # Radarsat-2 stripmap ultra-fine mode
 # from Table 2 in Jung et al. (2014)
 RSAT2 = {
+    # orbit
+    'altitude'                   : 798e3,     # m
+    'orbit_inclination'          : 98.6,      # deg
+    'repeat_cycle'               : 14,        # day, 14.29 orbits per day (14 7/24)
+    # sar / antenna
     'carrier_frequency'          : 5.405e9,   # Hz
-    'altitude'                   : 798e3,     # m, mean value
     'antenna_length'             : 6.55,      # m
     'doppler_bandwidth'          : 2308,      # Hz
     'pulse_repetition_frequency' : 3637,      # Hz
@@ -297,12 +351,32 @@ RSAT2 = {
     'ground_range_pixel_size'    : 2.1,       # m
 }
 
+# Radarsat Constellation Mission
+# https://www.asc-csa.gc.ca/eng/satellites/radarsat/technical-features/radarsat-comparison.asp
+RCM = {
+    # orbit
+    'altitude'                   : 600.5e3,   # m, mean value, 586-615 km
+    'orbit_inclination'          : 97.74,     # deg
+    'repeat_cycle'               : 14,        # day, 14.92 orbits per day (14 11/12)
+    # sar / antenna
+    'carrier_frequency'          : 5.405e9,   # Hz
+    'antenna_length'             : 6.75,      # m
+    'antenna_width'              : 1.38,      # m
+}
+
 # GaoFen-3
 # Table 2 & 6 in https://directory.eoportal.org/web/eoportal/satellite-missions/g/gaofen-3
+# https://www.eoportal.org/satellite-missions/gaofen-3
+# Li et al. (2018, RS) at https://doi.org/10.3390/rs10121929
 GF3 = {
-    'carrier_frequency'          : 5.4e9,     # Hz
+    # orbit
     'altitude'                   : 755e3,     # m
+    'orbit_inclination'          : 98.41,     # deg
+    'repeat_cycle'               : 29,        # day
+    # sar / antenna
+    'carrier_frequency'          : 5.4e9,     # Hz
     'antenna_length'             : 15,        # m
+    'antenna_width'              : 1.5,       # m
     'sampling_frequency'         : 533.33e6,  # Hz
 }
 
@@ -314,8 +388,12 @@ GF3 = {
 #   1. Table 2 & Fig. 5d in Jung et al. (2014)
 #   2. Table 3-1 & 7-5 in https://sentinel.esa.int/documents/247904/1877131/Sentinel-1-Product-Definition
 SEN = {
-    'carrier_frequency'          : 5.405e9,   # Hz
+    # orbit
     'altitude'                   : 705e3,     # m, mean value
+    'orbit_inclination'          : 98.18,     # deg
+    'repeat_cycle'               : 12,        # day, single satellite
+    # sar / antenna
+    'carrier_frequency'          : 5.405e9,   # Hz
     'antenna_length'             : 12.3,      # m
     'antenna_width'              : 0.82,      # m
     'doppler_bandwidth'          : 380,       # Hz
@@ -335,9 +413,14 @@ SEN = {
 
 # Seasat
 # from Table 6-1 in Kim and Jordan (2006)
+# https://www.eoportal.org/satellite-missions/seasat
 SEASAT = {
+    # orbit
+    'altitude'                   : 787e3,     # m, mean value, 775-799 km
+    'orbit_inclination'          : 108.0,     # deg
+    'repeat_cycle'               : 17,        # day
+    # sar / antenna
     'carrier_frequency'          : 1.275e9,   # Hz
-    'altitude'                   : 787e3,     # m, mean value
     'antenna_length'             : 10.74,     # m
     'antenna_width'              : 2.16,      # m
     'pulse_repetition_frequency' : 1555,      # Hz, 1463-1647
@@ -346,10 +429,16 @@ SEASAT = {
 
 # JERS-1
 # from Table 3 in Jung et al. (2014)
+# https://www.eoportal.org/satellite-missions/jers-1
 JERS = {
-    'carrier_frequency'          : 1.275e9,   # Hz
+    # orbit
     'altitude'                   : 568e3,     # m, mean value
+    'orbit_inclination'          : 97.7,      # deg
+    'repeat_cycle'               : 44,        # day
+    # sar / antenna
+    'carrier_frequency'          : 1.275e9,   # Hz
     'antenna_length'             : 11.92,     # m
+    'antenna_width'              : 2.2,       # m
     'doppler_bandwidth'          : 1157,      # Hz
     'pulse_repetition_frequency' : 1600,      # Hz, 1505-1606
     'chirp_bandwidth'            : 15.00e6,   # Hz
@@ -360,9 +449,14 @@ JERS = {
 
 # ALOS PALSAR FBS (fine beam single polarization) mode
 # from Table 3 in Jung et al. (2014)
+# https://www.eorc.jaxa.jp/ALOS/en/alos/a1_about_e.htm
 ALOS = {
-    'carrier_frequency'          : 1.270e9,   # Hz
+    # orbit
     'altitude'                   : 691.65e3,  # m, mean value
+    'orbit_inclination'          : 98.16,     # deg
+    'repeat_cycle'               : 46,        # day, sub cycle: 2 days
+    # sar / antenna
+    'carrier_frequency'          : 1.270e9,   # Hz
     'antenna_length'             : 8.9,       # m
     'doppler_bandwidth'          : 1700,      # Hz
     'pulse_repetition_frequency' : 2160,      # Hz
@@ -388,8 +482,12 @@ ALOS = {
 #                                            (FP:30)  (FP:30) (5 looks)
 # Notes: FP for full polarization
 ALOS2 = {
-    'carrier_frequency'          : 1.2575e9,  # Hz
+    # orbit
     'altitude'                   : 628e3,     # m, mean value
+    'orbit_inclination'          : 97.9,      # deg
+    'repeat_cycle'               : 14,        # day
+    # sar / antenna
+    'carrier_frequency'          : 1.2575e9,  # Hz
     'antenna_length'             : 9.9,       # m
     'antenna_width'              : 2.9,       # m
     'doppler_bandwidth'          : 1515,      # Hz
@@ -405,22 +503,41 @@ ALOS2 = {
     }
 }
 
+# ALOS-4 PALSAR-3
+# https://www.eorc.jaxa.jp/ALOS/en/alos-4/a4_about_e.htm
+ALOS4 = {
+    # orbit (same as ALOS-2)
+    'altitude'                   : 628e3,     # m, mean value
+    'orbit_inclination'          : 97.9,      # deg
+    'repeat_cycle'               : 14,        # day, (15-3/14 rev/day)
+}
+
 # SAOCOM-1A/B stripmap
 # from Giudici et al. (2017) and
 # https://directory.eoportal.org/web/eoportal/satellite-missions/s/saocom
+# https://www.eoportal.org/satellite-missions/saocom
 SAOCOM = {
-    'carrrier_frequency'         : 1.27414e9, # Hz
+    # orbit
     'altitude'                   : 619.6e3,   # m, mean value
+    'orbit_inclination'          : 97.86,     # deg
+    'repeat_cycle'               : 16,        # day, single satellite
+    # sar / antenna
+    'carrrier_frequency'         : 1.27414e9, # Hz
     'antenna_length'             : 10,        # m
     'pulse_repetition_frequency' : 4545,      # Hz
     'sampling_frequency'         : 50.0e6,    # Hz
 }
 
 # LuTan-1 (stripmap mode)
+# Table 1 from Liu et al. (2022, EUSAR) at https://ieeexplore.ieee.org/document/9944327
 # preliminary version: the azimuth bandwidth/frequency/pixelsize might change
 LT1 = {
-    'carrier_frequency'          : 1.26e9,    # Hz
+    # orbit
     'altitude'                   : 607e3,     # m, mean value
+    'orbit_inclination'          : 97.8,      # deg
+    'repeat_cycle'               : 8,         # day, single satellite
+    # sar / antenna
+    'carrier_frequency'          : 1.26e9,    # Hz
     'antenna_length'             : 9.8,       # m
     'antenna_width'              : 3.4,       # m
     'doppler_bandwidth'          : 2544,      # Hz
@@ -435,8 +552,12 @@ LT1 = {
 # NISAR
 # https://nisar.jpl.nasa.gov/system/documents/files/26_NISAR_FINAL_9-6-19.pdf
 NISAR_L = {
-    'carrier_frequency'          : 1.257e9,   # Hz
+    # orbit
     'altitude'                   : 747e3,     # m, mean value
+    'orbit_inclination'          : 98.4,      # deg
+    'repeat_cycle'               : 12,        # day
+    # sar / antenna
+    'carrier_frequency'          : 1.257e9,   # Hz
     'antenna_length'             : 12,        # m
     'pulse_repetition_frequency' : 1650,      # Hz
     'chirp_bandwidth'            : 80.0e6,    # Hz
@@ -458,11 +579,15 @@ SENSOR_DICT = {
     'ers'   : ERS,
     'env'   : ENV,
     'sen'   : SEN,
+    'rsat1' : RSAT1,
     'rsat2' : RSAT2,
+    'rcm'   : RCM,
+    'gf3'   : GF3,
     # L-band
     'jers'  : JERS,
     'alos'  : ALOS,
     'alos2' : ALOS2,
+    'alos4' : ALOS4,
     'lt1'   : LT1,
     'ni'    : NISAR_L,
 }
