@@ -122,7 +122,8 @@ def calc_num_triplet_with_nonzero_integer_ambiguity(ifgram_file, mask_file=None,
     # calculate number of nonzero closure phase
     ds_size = (C.shape[0] * 2 + C.shape[1]) * length * width * 4
     num_loop = int(np.ceil(ds_size * 2 / (max_memory * 1024**3)))
-    step = int(np.rint(length / num_loop / 10) * 10)
+    # ensure a min step size of 10
+    step = int(np.ceil(length / num_loop / 10)) * 10
     num_loop = int(np.ceil(length / step))
     num_nonzero_closure = np.zeros((length, width), dtype=np.float32)
     msg = 'calculating the number of triplets with non-zero integer ambiguity of closure phase ...'
@@ -244,7 +245,8 @@ def get_common_region_int_ambiguity(ifgram_file, cc_mask_file, water_mask_file=N
         for i in range(num_label):
             common_reg = common_regions[i]
             # sample_coords
-            idx = sorted(np.random.choice(common_reg.area, num_sample, replace=False))
+            rng = np.random.default_rng()
+            idx = sorted(rng.choice(int(common_reg.area), num_sample, replace=False))
             common_reg.sample_coords = common_reg.coords[idx, :].astype(int)
 
             # solve for int_ambiguity
