@@ -178,7 +178,8 @@ DATA_TYPE_NUMPY2ISCE = {
 
 # 4 - GAMMA
 DATA_TYPE_GAMMA2NUMPY = {
-    'fcomplex' : 'float64',
+    'fcomplex' : 'complex64',
+    'scomplex' : 'complex32',
 }
 
 # single file (data + attributes) supported by GDAL
@@ -206,6 +207,21 @@ SPECIAL_STR2NUM = {
     'nan'   : np.nan,
 }
 
+GMTSAR_SENSOR_ID2NAME = {
+    1 : 'ers',
+    2 : 'ers',
+    3 : 'rs1',
+    4 : 'env',
+    5 : 'alos',
+    6 : 'tsx',
+    7 : 'csk',
+    8 : 'csk',
+    9 : 'rs2',
+    10: 'sen',
+    11: 'gf3',
+    12: 'lt1',
+}
+
 
 #########################################################################
 def numpy_to_gdal_dtype(np_dtype: DTypeLike) -> int:
@@ -678,11 +694,11 @@ def read_binary_file(fname, datasetName=None, box=None, xstep=1, ystep=1):
             if datasetName and datasetName.startswith(('az', 'azimuth')):
                 band = 2
 
-        elif fext == '.slc':
+        elif fext in ['.slc', '.rslc']:
             data_type = data_type if 'DATA_TYPE' in atr.keys() else 'complex32'
             cpx_band = 'magnitude'
 
-        elif fext in ['.mli']:
+        elif fext in ['.mli', '.rmli']:
             byte_order = 'little-endian'
 
     # SNAP
@@ -1370,15 +1386,16 @@ def auto_no_data_value(meta):
         num_band = int(meta.get('BANDS', 0))
 
         # known file types
-        # isce2: dense offsets from topsApp.py
-        if processor == 'isce' and num_band == 2:
-            # isce2 dense offset
-            if fname.endswith('dense_offsets.bil'):
-                # from topsApp.py
+        if processor == 'isce':
+            if num_band == 2 and fname.endswith('dense_offsets.bil'):
+                # topsApp: dense offset
                 no_data_value = -10000.
-            elif fname.endswith('_denseoffset.off'):
-                # from alos2App.py
+            elif num_band == 2 and fname.endswith('_denseoffset.off'):
+                # alos2App: dense offset
                 no_data_value = 0.
+            elif num_band == 1 and fname.endswith(('alks_rg.off', 'alks_az.off')):
+                # alos2App: geometrical offset
+                no_data_value = -999999.0
             else:
                 no_data_value = None
 
@@ -1793,6 +1810,14 @@ def _attribute_gmtsar2roipac(prm_dict_in):
         else:
             prm_dict['ANTENNA_SIDE'] = '1'
 
+    # orbdir -> ORBIT_DIRECTION
+    key = 'orbdir'
+    if key in prm_dict_in.keys():
+        prm_dict['ORBIT_DIRECTION'] = {
+            'A' : 'ASCENDING',
+            'D' : 'DESCENDING',
+        }[prm_dict[key]]
+
     # SC_vel -> AZIMUTH_PIXEL_SIZE (in single look)
     key = 'SC_vel'
     if key in prm_dict_in.keys():
@@ -1814,6 +1839,9 @@ def _attribute_gmtsar2roipac(prm_dict_in):
     t_center = dt_center - int(dt_center)
     prm_dict['CENTER_LINE_UTC'] = str(t_center * 24. * 60. * 60.)
 
+    # SC_identity -> PLATFORM
+    prm_dict['PLATFORM'] = GMTSAR_SENSOR_ID2NAME[int(prm_dict['SC_identity'])]
+
     return prm_dict
 
 
@@ -1897,7 +1925,8 @@ def read_snap_dim(fname):
     bases = ds.find("MDElem[@name='Baselines']").findall("MDElem")[0].findall("MDElem")
 
     # date12
-    dates = [x.get('name').split(':')[1].strip() for x in bases]
+    # support both delimiters of : and _
+    dates = [re.split(':|_', x.get('name'))[1].strip() for x in bases][-2:]
     [date1, date2] = sorted(dt.datetime.strptime(x, '%d%b%Y').strftime('%Y%m%d') for x in dates)
     dim_dict['DATE12'] = f'{date1[2:]}-{date2[2:]}'
 
@@ -1959,38 +1988,44 @@ def read_binary(fname, shape, box=None, data_type='float32', byte_order='l',
     if not box:
         box = (0, 0, width, length)
 
-    if byte_order in ['b', 'big', 'big-endian', 'ieee-be']:
-        letter, digit = re.findall(r'(\d+|\D+)', data_type)
-        # convert into short style: float32 --> c4
-        if len(letter) > 1:
-            letter = letter[0]
-            digit = int(int(digit) / 8)
-        data_type = f'>{letter}{digit}'
-
     # read data
-    interleave = interleave.upper()
-    if interleave == 'BIL':
-        count = box[3] * width * num_band
-        data = np.fromfile(fname, dtype=data_type, count=count).reshape(-1, width*num_band)
-        c0 = width * (band - 1) + box[0]
-        c1 = width * (band - 1) + box[2]
-        data = data[box[1]:box[3], c0:c1]
-
-    elif interleave == 'BIP':
-        count = box[3] * width * num_band
-        data = np.fromfile(fname, dtype=data_type, count=count).reshape(-1, width*num_band)
-        inds = np.arange(box[0], box[2]) * num_band + band - 1
-        data = data[box[1]:box[3], inds]
-
-    elif interleave == 'BSQ':
-        count = (box[3] + length * (band - 1)) * width
-        data = np.fromfile(fname, dtype=data_type, count=count).reshape(-1, width)
-        r0 = length * (band - 1) + box[1]
-        r1 = length * (band - 1) + box[3]
-        data = data[r0:r1, box[0]:box[2]]
+    if data_type == 'complex32':
+        # for numpy un-supported data type: complex32
+        data = read_complex_int16(fname, box=box, byte_order=byte_order, cpx_band='complex')[0]
 
     else:
-        raise ValueError('unrecognized band interleaving:', interleave)
+        # for numpy supported data type
+        if byte_order in ['b', 'big', 'big-endian', 'ieee-be']:
+            letter, digit = re.findall(r'(\d+|\D+)', data_type)
+            # convert into short style: float32 --> c4
+            if len(letter) > 1:
+                letter = letter[0]
+                digit = int(int(digit) / 8)
+            data_type = f'>{letter}{digit}'
+
+        interleave = interleave.upper()
+        if interleave == 'BIL':
+            count = box[3] * width * num_band
+            data = np.fromfile(fname, dtype=data_type, count=count).reshape(-1, width*num_band)
+            c0 = width * (band - 1) + box[0]
+            c1 = width * (band - 1) + box[2]
+            data = data[box[1]:box[3], c0:c1]
+
+        elif interleave == 'BIP':
+            count = box[3] * width * num_band
+            data = np.fromfile(fname, dtype=data_type, count=count).reshape(-1, width*num_band)
+            inds = np.arange(box[0], box[2]) * num_band + band - 1
+            data = data[box[1]:box[3], inds]
+
+        elif interleave == 'BSQ':
+            count = (box[3] + length * (band - 1)) * width
+            data = np.fromfile(fname, dtype=data_type, count=count).reshape(-1, width)
+            r0 = length * (band - 1) + box[1]
+            r1 = length * (band - 1) + box[3]
+            data = data[r0:r1, box[0]:box[2]]
+
+        else:
+            raise ValueError('unrecognized band interleaving:', interleave)
 
     # adjust output band for complex data
     if data_type.replace('>', '').startswith('c'):
@@ -2331,49 +2366,60 @@ def read_real_float32(fname, box=None, byte_order='l'):
     return data, atr
 
 
-def read_complex_int16(fname, box=None, byte_order='l', cpx=False):
+def read_complex_int16(fname, box=None, byte_order='l', cpx_band='complex'):
     """Read complex int 16 data matrix, i.e. GAMMA SCOMPLEX file (.slc)
 
     Gamma file: .slc
 
-    Inputs:
-       file: complex data matrix (cpx_int16)
-       box: 4-tuple defining the left, upper, right, and lower pixel coordinate.
-    Example:
-       data,rsc = read_complex_int16('100102.slc')
-       data,rsc = read_complex_int16('100102.slc',(100,1200,500,1500))
+    Parameters: fname      - str, path to the binary file
+                box        - tuple(int), bounding box in (x0, y0, x1, y1)
+                byte_order - str, byte order in big/little-endian
+                cpx_band   - str, cpx / real / imag / mag / pha
+    Returns:    data       - np.ndarray, 2D matrix
+                atr        - dict, metadata
+    Example: data, atr = read_complex_int16('100102.slc')
+             data, atr = read_complex_int16('100102.slc', box=(100,1200,500,1500))
     """
 
+    # read attributes
     atr = read_attribute(fname)
     if 'DATA_TYPE' not in atr.keys():
         atr['DATA_TYPE'] = 'complex32'
     width = int(float(atr['WIDTH']))
     length = int(float(atr['LENGTH']))
+
+    # box
     if not box:
         box = [0, 0, width, length]
 
+    # data_type
     data_type = 'i2'
     if byte_order in ['b', 'big', 'big-endian', 'ieee-be']:
         data_type = '>i2'
 
-    data = np.fromfile(fname,
-                       dtype=data_type,
-                       count=box[3]*2*width).reshape(box[3], 2*width)
-    data = data[box[1]:box[3],
-                2*box[0]:2*box[2]].flatten()
+    # read from file
+    data = np.fromfile(fname, dtype=data_type, count=box[3]*2*width).reshape(box[3], 2*width)
+    data = data[box[1]:box[3], 2*box[0]:2*box[2]].flatten()
 
     odd_idx = np.arange(1, len(data), 2)
-    real = data[odd_idx-1].reshape(box[3]-box[1],
-                                   box[2]-box[0])
-    imag = data[odd_idx].reshape(box[3]-box[1],
-                                 box[2]-box[0])
+    real = data[odd_idx-1].reshape(box[3]-box[1], box[2]-box[0])
+    imag = data[odd_idx].reshape(box[3]-box[1], box[2]-box[0])
 
-    if cpx:
-        return real, imag, atr
+    # adjust output band for complex data
+    if cpx_band.startswith('real'):
+        data = real
+    elif cpx_band.startswith('imag'):
+        data = imag
+    elif cpx_band.startswith(('mag', 'amp')):
+        data = np.hypot(imag, real)
+    elif cpx_band.startswith('pha'):
+        data = np.arctan2(imag, real)
+    elif cpx_band.startswith(('cpx', 'complex')):
+        data = real + 1j * imag
     else:
-        amplitude = np.hypot(imag, real)
-        phase = np.arctan2(imag, real)
-        return amplitude, phase, atr
+        raise ValueError('unrecognized complex band:', cpx_band)
+
+    return data, atr
 
 
 def read_real_int16(fname, box=None, byte_order='l'):
