@@ -264,23 +264,25 @@ def transect_yx(z, atr, start_yx, end_yx, interpolation='nearest'):
     """Extract 2D matrix (z) value along the line [x0,y0;x1,y1]
     Link: http://stackoverflow.com/questions/7878398/how-to-extract-an-arbitrary-line-of-values-from-a-numpy-array
 
-    Parameters: z : (np.array) 2D data matrix
-                atr : (dict) attribute
+    Parameters: z        : (np.ndarray) 2D data matrix
+                atr      : (dict) attribute
                 start_yx : (list) y,x coordinate of start point
-                end_yx : (list) y,x coordinate of end   point
+                end_yx   : (list) y,x coordinate of end   point
                 interpolation : str, sampling/interpolation method, including:
                     'nearest' - nearest neighbour
                     'linear'  - linear  spline interpolation (order of 1)
                     'cubic'   - cubic   spline interpolation (order of 3)
                     'quintic' - quintic spline interpolation (order of 5)
 
-    Returns:    transect: (dict) containing 1D matrix:
-                    'X' - 1D np.array for X/column coordinates in float32
-                    'Y' - 1D np.array for Y/row.   coordinates in float32
-                    'value' - 1D np.array for z value in float32
+    Returns:    transect : (dict) containing 1D matrix:
+                    'X'        - 1D np.array for X/column coordinates in float32
+                    'Y'        - 1D np.array for Y/row    coordinates in float32
+                    'value'    - 1D np.array for z value in float32
                     'distance' - 1D np.array for distance in float32
 
-    Example: transect = transect_yx(dem, demRsc, [10,15], [100,115])
+    Example: from mintpy.utils import readfile, utils as ut
+             dem, atr = readfile.read('srtm1.dem.wgs84')
+             txn = transect_yx(dem, atr, [10,15], [100,115])
     """
     interpolation = interpolation.lower()
     [y0, x0] = start_yx
@@ -325,10 +327,13 @@ def transect_yx(z, atr, start_yx, end_yx, interpolation='nearest'):
     earth_radius = 6.3781e6    # in meter
     dist_unit = 'm'
     if 'Y_FIRST' in atr.keys():
-        [lat0, lat1] = coordinate(atr).yx2lalo([y0, y1], coord_type='y')
-        lat_c = (lat0 + lat1) / 2.
-        x_step = float(atr['X_STEP']) * np.pi/180.0 * earth_radius * np.cos(lat_c * np.pi/180)
-        y_step = float(atr['Y_STEP']) * np.pi/180.0 * earth_radius
+        y_step = float(atr['Y_STEP'])
+        x_step = float(atr['X_STEP'])
+        if not atr.get('UTM_ZONE', None):   # WGS84 lat/lon
+            [lat0, lat1] = coordinate(atr).yx2lalo([y0, y1], [x0, x1])[0]
+            lat_c = (lat0 + lat1) / 2.
+            y_step *= np.pi/180.0 * earth_radius
+            x_step *= np.pi/180.0 * earth_radius * np.cos(lat_c * np.pi/180)
     else:
         try:
             x_step = range_ground_resolution(atr)
@@ -356,10 +361,31 @@ def transect_yx(z, atr, start_yx, end_yx, interpolation='nearest'):
 
 
 def transect_lalo(z, atr, start_lalo, end_lalo, interpolation='nearest'):
-    """Extract 2D matrix (z) value along the line [start_lalo, end_lalo]"""
+    """Extract 2D matrix (z) value along the line [start_lalo, end_lalo]
+
+    Parameters: z        : (np.ndarray) 2D data matrix
+                atr      : (dict) attribute
+                start_yx : (list) y,x coordinate of start point
+                end_yx   : (list) y,x coordinate of end   point
+                interpolation : str, sampling/interpolation method, including:
+                    'nearest' - nearest neighbour
+                    'linear'  - linear  spline interpolation (order of 1)
+                    'cubic'   - cubic   spline interpolation (order of 3)
+                    'quintic' - quintic spline interpolation (order of 5)
+
+    Returns:    transect : (dict) containing 1D matrix:
+                    'X'        - 1D np.array for X/column coordinates in float32
+                    'Y'        - 1D np.array for Y/row    coordinates in float32
+                    'value'    - 1D np.array for z value in float32
+                    'distance' - 1D np.array for distance in float32
+
+    Example: from mintpy.utils import readfile, utils as ut
+             vel, atr = readfile.read('geo_velocity_msk.h5')
+             txn = transect_yx(vel, atr, [30.0, 110.0], [30.2, 111.3])
+    """
     coord = coordinate(atr)
-    [y0, y1] = coord.lalo2yx([start_lalo[0], end_lalo[0]], coord_type='lat')
-    [x0, x1] = coord.lalo2yx([start_lalo[1], end_lalo[1]], coord_type='lon')
+    [y0, y1], [x0, x1] = coord.lalo2yx([start_lalo[0], end_lalo[0]],
+                                       [start_lalo[1], end_lalo[1]])
     transect = transect_yx(z, atr, [y0, x0], [y1, x1], interpolation)
     return transect
 
