@@ -1,13 +1,20 @@
-# grab version / date of the latest commit
-
+############################################################
+# Program is part of MintPy                                #
+# Copyright (c) 2013, Zhang Yunjun, Heresh Fattahi         #
+# Author: Zhang Yunjun, Mar 2018                           #
+############################################################
+# Recommend import:
+#   from mintpy.version import version, version_description, logo
 
 import collections
 import os
 import subprocess
+from importlib.metadata import PackageNotFoundError, metadata
 
 ###########################################################################
 Tag = collections.namedtuple('Tag', 'version date')
 release_history = (
+    Tag('1.6.1', '2024-07-31'),
     Tag('1.6.0', '2024-05-09'),
     Tag('1.5.3', '2023-11-23'),
     Tag('1.5.2', '2023-08-09'),
@@ -35,11 +42,9 @@ release_history = (
     Tag('0.2.0', '2016-07-14'),
     Tag('0.1.0', '2015-11-23'),
 )
-release_version = release_history[0].version
-release_date = release_history[0].date
 
 def get_version_info():
-    """Grab version and date of the latest commit from a git repository"""
+    """Grab version and its date from a git repository."""
     # go to the repository directory
     dir_orig = os.getcwd()
     os.chdir(os.path.dirname(os.path.dirname(__file__)))
@@ -49,28 +54,42 @@ def get_version_info():
         cmd = "git describe --tags"
         version = subprocess.check_output(cmd.split(), stderr=subprocess.DEVNULL)
         version = version.decode('utf-8').strip()[1:]
-
         # if there are new commits after the latest release
         if '-' in version:
             version, num_commit = version.split('-')[:2]
             version += f'.post{num_commit}'
-
         cmd = "git log -1 --date=short --format=%cd"
-        date = subprocess.check_output(cmd.split(), stderr=subprocess.DEVNULL)
-        date = date.decode('utf-8').strip()
-
+        version_date = subprocess.check_output(cmd.split(), stderr=subprocess.DEVNULL)
+        version_date = version_date.decode('utf-8').strip()
     except:
         # use the latest release version/date
-        version = release_version
-        date = release_date
+        version = release_history[0].version
+        version_date = release_history[0].date
 
     # go back to the original directory
     os.chdir(dir_orig)
-    return version, date
+    return version, version_date
+
+
+def get_version_info_v2():
+    """Grab the version and its date from a git repository.
+    Note by Yunjun on 5 Dec 2023: could not grab release/commit date info
+        using importlib, thus, return None always.
+    """
+    try:
+        package_name = os.path.basename(os.path.dirname(__file__))
+        package = metadata(package_name)
+        version = package['Version']
+    except PackageNotFoundError:
+        print('package is not installed!\n'
+          'Please follow the installation instructions in the README.md.\n'
+          'Or, to just get the version number, use:\n'
+          '   python -m setuptools_scm')
+        version = None
+    return version, None
 
 
 ###########################################################################
-
 version, version_date = get_version_info()
 version_description = """MintPy version {v}, date {d}""".format(
     v=version,
